package com.chelvc.framework.base.config;

import lombok.Data;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Configuration;

/**
 * Http请求配置属性
 *
 * @author Woody
 * @date 2024/1/30
 */
@Data
@Configuration
@ConfigurationProperties("httpclient")
public class HttpClientProperties {
    /**
     * 连接池的最大连接数
     */
    private int maxTotal = 200;

    /**
     * 同路由的并发数
     */
    private int maxPerRoute = 50;

    /**
     * 重试次数
     */
    private int retryCount = 1;

    /**
     * 客户端和服务器建立连接超时时间（毫秒）
     */
    private int connectTimeout = 10000;

    /**
     * 客户端从服务器读取数据包的间隔超时时间（毫秒）
     */
    private int socketTimeout = 30000;

    /**
     * 长连接保持时间（毫秒）
     */
    private int keepAliveTime = 60000;

    /**
     * 从连接池获取连接的超时时间（毫秒）
     */
    private int connectionRequestTimeout = 200;

    /**
     * 连接空间超时时间（毫秒）
     */
    private int maxIdleTime = 30000;
}
