package com.chelvc.framework.base.config;

import java.util.concurrent.ThreadPoolExecutor;

import com.chelvc.framework.common.util.JacksonUtils;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.task.TaskExecutionProperties;
import org.springframework.boot.autoconfigure.task.TaskSchedulingProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.task.TaskExecutor;
import org.springframework.scheduling.TaskScheduler;
import org.springframework.scheduling.annotation.EnableAsync;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.concurrent.ThreadPoolTaskExecutor;
import org.springframework.scheduling.concurrent.ThreadPoolTaskScheduler;

/**
 * Spring task 配置
 *
 * @author Woody
 * @date 2024/1/30
 */
@Slf4j
@Configuration
@EnableScheduling
@EnableAsync(proxyTargetClass = true)
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class SpringTaskConfigurer {
    private final SpringTaskProperties properties;

    @Bean
    public TaskExecutor taskExecutor() {
        TaskExecutionProperties config = this.properties.getExecution();
        log.info("Initialize task executor with configuration: {}", JacksonUtils.serialize(config));
        ThreadPoolTaskExecutor executor = new ThreadPoolTaskExecutor();
        executor.setThreadNamePrefix(config.getThreadNamePrefix());
        executor.setCorePoolSize(config.getPool().getCoreSize());
        executor.setMaxPoolSize(config.getPool().getMaxSize());
        executor.setQueueCapacity(config.getPool().getQueueCapacity());
        executor.setAllowCoreThreadTimeOut(config.getPool().isAllowCoreThreadTimeout());
        executor.setKeepAliveSeconds((int) config.getPool().getKeepAlive().getSeconds());
        executor.setWaitForTasksToCompleteOnShutdown(config.getShutdown().isAwaitTermination());
        executor.setAwaitTerminationSeconds((int) config.getShutdown().getAwaitTerminationPeriod().getSeconds());
        executor.setRejectedExecutionHandler(new ThreadPoolExecutor.AbortPolicy());
        executor.initialize();
        executor.getThreadPoolExecutor().prestartAllCoreThreads();
        return executor;
    }

    @Bean
    public TaskScheduler taskScheduler() {
        TaskSchedulingProperties config = this.properties.getScheduling();
        log.info("Initialize task scheduler with configuration: {}", JacksonUtils.serialize(config));
        ThreadPoolTaskScheduler scheduler = new ThreadPoolTaskScheduler();
        scheduler.setThreadNamePrefix(config.getThreadNamePrefix());
        scheduler.setPoolSize(config.getPool().getSize());
        scheduler.setWaitForTasksToCompleteOnShutdown(config.getShutdown().isAwaitTermination());
        scheduler.setAwaitTerminationSeconds((int) config.getShutdown().getAwaitTerminationPeriod().getSeconds());
        scheduler.initialize();
        return scheduler;
    }
}
