package com.chelvc.framework.base.crypto;

import java.time.Duration;

import com.chelvc.framework.common.util.StringUtils;
import com.github.benmanes.caffeine.cache.Cache;
import com.github.benmanes.caffeine.cache.Caffeine;
import lombok.NonNull;

/**
 * 基于缓存的加解密处理实现
 *
 * @author Woody
 * @date 2024/12/27
 */
public class CacheableCipherHandler implements CipherHandler {
    protected final CipherHandler delegate;
    private final Cache<String, String> encrypts;
    private final Cache<String, String> decrypts;

    public CacheableCipherHandler(@NonNull CipherHandler delegate, long capacity, @NonNull Duration duration) {
        this.delegate = delegate;
        this.encrypts = Caffeine.newBuilder().maximumSize(capacity).expireAfterAccess(duration).build();
        this.decrypts = Caffeine.newBuilder().maximumSize(capacity).expireAfterAccess(duration).build();
    }

    @Override
    public byte[] encrypt(byte[] bytes) {
        return this.delegate.encrypt(bytes);
    }

    @Override
    public byte[] decrypt(byte[] bytes) {
        return this.delegate.decrypt(bytes);
    }

    @Override
    public String encrypt(String plaintext) {
        return StringUtils.isEmpty(plaintext) ? plaintext : this.encrypts.get(plaintext, this.delegate::encrypt);
    }

    @Override
    public String decrypt(String ciphertext) {
        return StringUtils.isEmpty(ciphertext) ? ciphertext : this.decrypts.get(ciphertext, this.delegate::decrypt);
    }
}
