package com.chelvc.framework.base.interceptor;

import java.io.BufferedReader;
import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import javax.servlet.ReadListener;
import javax.servlet.ServletInputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletRequestWrapper;

import com.chelvc.framework.base.util.HttpUtils;
import lombok.NonNull;

/**
 * 可缓存请求体的请求包装器实现
 *
 * @author Woody
 * @date 2024/1/30
 */
public class BufferedRequestWrapper extends HttpServletRequestWrapper {
    private final byte[] body;

    public BufferedRequestWrapper(@NonNull HttpServletRequest request) throws IOException {
        this(request, HttpUtils.getBody(request));
    }

    public BufferedRequestWrapper(@NonNull HttpServletRequest request, @NonNull byte[] body) {
        super(request);
        this.body = body;
    }

    @Override
    public BufferedReader getReader() throws IOException {
        return new BufferedReader(new InputStreamReader(this.getInputStream()));
    }

    @Override
    public ServletInputStream getInputStream() throws IOException {
        return new BufferedServletInputStream(this.body);
    }

    /**
     * 可缓存的Servlet输入流实现
     */
    public static class BufferedServletInputStream extends ServletInputStream {
        private final byte[] bytes;
        private final InputStream stream;

        public BufferedServletInputStream(@NonNull byte[] bytes) {
            this.stream = new ByteArrayInputStream(this.bytes = bytes);
        }

        /**
         * 获取字节数组
         *
         * @return 字节数组
         */
        public byte[] bytes() {
            return this.bytes;
        }

        @Override
        public int read() throws IOException {
            return this.stream.read();
        }

        @Override
        public int available() throws IOException {
            return this.stream.available();
        }

        @Override
        public boolean isReady() {
            return true;
        }

        @Override
        public boolean isFinished() {
            return false;
        }

        @Override
        public void setReadListener(ReadListener listener) {
            throw new UnsupportedOperationException();
        }
    }
}
