package com.chelvc.framework.base.logic;

import java.util.Collections;
import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;
import java.util.stream.Stream;

import com.chelvc.framework.common.util.ObjectUtils;
import com.chelvc.framework.common.util.StringUtils;
import lombok.Getter;
import lombok.NonNull;

/**
 * 判断逻辑对象
 *
 * @author Woody
 * @date 2025/2/25
 */
public abstract class Judge extends Expression {
    @Getter
    protected final String left;
    @Getter
    protected final String right;
    @Getter
    protected final String symbol;
    protected final Variable primary;
    protected final List<Variable> values;

    public Judge(@NonNull String left, @NonNull String right, @NonNull String symbol) {
        this.left = left;
        this.right = right;
        this.symbol = symbol;
        this.primary = new Variable(left);
        List<Variable> values = Stream.of(right.split(",")).map(String::trim).filter(StringUtils::notEmpty)
                .map(Variable::new).collect(Collectors.toList());
        this.values = ObjectUtils.isEmpty(values) ? Collections.emptyList() : values;
    }

    /**
     * 判断比较值是否匹配
     *
     * @param left  运算符左值
     * @param right 运算符右值
     * @return true/false
     */
    public abstract boolean matches(CharSequence left, CharSequence right);

    @Override
    public boolean eval(@NonNull VariableParser parser) {
        if (ObjectUtils.notEmpty(this.values)) {
            CharSequence left = this.primary.parse(parser);
            for (Variable value : this.values) {
                if (this.matches(left, value.parse(parser))) {
                    return true;
                }
            }
        }
        return false;
    }

    @Override
    public int hashCode() {
        return Objects.hash(this.left, this.right, this.symbol);
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == this) {
            return true;
        } else if (!(obj instanceof Judge)) {
            return false;
        }
        Judge judge = (Judge) obj;
        return Objects.equals(this.left, judge.left) && Objects.equals(this.right, judge.right)
                && Objects.equals(this.symbol, judge.symbol);
    }

    @Override
    public String toString() {
        return this.left + SPACE + this.symbol + SPACE + this.right;
    }
}
