package com.chelvc.framework.base.logic;

import java.util.Objects;

import lombok.NonNull;

/**
 * 逻辑且/或对象
 *
 * @author Woody
 * @date 2025/2/25
 */
public abstract class Logic extends Expression {
    protected final String symbol;
    protected final Expression left;
    protected final Expression right;

    public Logic(@NonNull Expression left, @NonNull Expression right, @NonNull String symbol) {
        this.left = left;
        this.right = right;
        this.symbol = symbol;
    }

    @Override
    public int hashCode() {
        return Objects.hash(this.left, this.right, this.symbol);
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == this) {
            return true;
        } else if (!(obj instanceof Logic)) {
            return false;
        }
        Logic logic = (Logic) obj;
        return Objects.equals(this.left, logic.left) && Objects.equals(this.right, logic.right)
                && Objects.equals(this.symbol, logic.symbol);
    }

    @Override
    public String toString() {
        StringBuilder buffer = new StringBuilder();
        if (this.left instanceof Logic) {
            buffer.append(LEFT_BRACKET).append(this.left).append(RIGHT_BRACKET);
        } else {
            buffer.append(this.left);
        }
        buffer.append(SPACE).append(this.symbol).append(SPACE);
        if (this.right instanceof Logic) {
            buffer.append(LEFT_BRACKET).append(this.right).append(RIGHT_BRACKET);
        } else {
            buffer.append(this.right);
        }
        return buffer.toString();
    }
}
