package com.chelvc.framework.cloud.context;

import java.util.Collections;
import java.util.Map;
import java.util.Set;

import com.chelvc.framework.base.context.PropertyRefreshListener;
import com.chelvc.framework.common.util.ObjectUtils;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.context.environment.EnvironmentChangeEvent;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationListener;
import org.springframework.stereotype.Component;

/**
 * 环境配置变更监听器
 *
 * @author Woody
 * @date 2024/6/14
 */
@Slf4j
@Component
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class EnvironmentChangeListener implements ApplicationListener<EnvironmentChangeEvent> {
    private final ApplicationContext applicationContext;

    @Override
    public void onApplicationEvent(EnvironmentChangeEvent event) {
        Set<String> keys = ObjectUtils.ifNull(event.getKeys(), Collections::emptySet);
        Map<?, PropertyRefreshListener> listeners =
                this.applicationContext.getBeansOfType(PropertyRefreshListener.class);
        if (ObjectUtils.notEmpty(listeners)) {
            listeners.forEach((name, listener) -> {
                try {
                    listener.refreshProperty(keys);
                } catch (Exception e) {
                    log.error("Property refresh failed: {}", listener.getClass().getName(), e);
                }
            });
        }
    }
}
