package com.chelvc.framework.common.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import javax.validation.Constraint;
import javax.validation.Payload;

import com.chelvc.framework.common.validator.DateValidator;

/**
 * 日期参数校验注解
 *
 * @author Woody
 * @date 2024/4/27
 */
@Documented
@Retention(RetentionPolicy.RUNTIME)
@Constraint(validatedBy = DateValidator.class)
@Target({ElementType.FIELD, ElementType.PARAMETER})
public @interface Dates {
    /**
     * 获取当前日期时间与最小日期时间差值（秒），0: 当前时间、<0: 过去时间、>0: 未来时间
     *
     * @return 时间差值（秒）
     */
    int min() default Integer.MIN_VALUE;

    /**
     * 获取当前日期时间与最大日期时间差值（秒），0: 当前时间、<0: 过去时间、>0: 未来时间
     *
     * @return 时间差值（秒）
     */
    int max() default Integer.MAX_VALUE;

    /**
     * 获取异常消息
     *
     * @return 异常消息
     */
    String message() default "Invalid date";

    /**
     * 获取对象分组（固定写法）
     *
     * @return 对象数组
     */
    Class<?>[] groups() default {};

    /**
     * 获取载体对象（固定写法）
     *
     * @return 载体对象数组
     */
    Class<? extends Payload>[] payload() default {};
}
