package com.chelvc.framework.common.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import java.math.RoundingMode;

import com.chelvc.framework.common.jackson.JacksonDecimalSerializer;
import com.fasterxml.jackson.annotation.JacksonAnnotationsInside;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;

/**
 * 小数序列化注解
 *
 * @author Woody
 * @date 2024/1/30
 */
@Documented
@JacksonAnnotationsInside
@Target(ElementType.FIELD)
@Retention(RetentionPolicy.RUNTIME)
@JsonSerialize(using = JacksonDecimalSerializer.class)
public @interface Decimal {
    /**
     * 默认小数保留位数
     */
    int DEFAULT_SCALE = 2;

    /**
     * 获取小数保留位数
     *
     * @return 小数保留位数
     */
    int scale() default DEFAULT_SCALE;

    /**
     * 获取小数舍弃模式
     *
     * @return 小数舍弃模式
     */
    RoundingMode mode() default RoundingMode.HALF_UP;

    /**
     * 是否去掉多余的0
     *
     * @return true/false
     */
    boolean trimZeros() default false;
}
