package com.chelvc.framework.common.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import javax.validation.Constraint;
import javax.validation.Payload;

import com.chelvc.framework.common.validator.NumberValidator;

/**
 * 数字参数校验注解
 *
 * @author Woody
 * @date 2024/4/28
 */
@Documented
@Retention(RetentionPolicy.RUNTIME)
@Constraint(validatedBy = NumberValidator.class)
@Target({ElementType.FIELD, ElementType.PARAMETER})
public @interface Numbers {
    /**
     * 获取最小值，当值>0时生效
     *
     * @return 数字最小值
     */
    double min() default -1;

    /**
     * 获取最大值，当值>0时生效
     *
     * @return 数字最大值
     */
    double max() default -1;

    /**
     * 获取异常消息
     *
     * @return 异常消息
     */
    String message() default "Invalid number";

    /**
     * 获取对象分组（固定写法）
     *
     * @return 对象数组
     */
    Class<?>[] groups() default {};

    /**
     * 获取载体对象（固定写法）
     *
     * @return 载体对象数组
     */
    Class<? extends Payload>[] payload() default {};
}
