package com.chelvc.framework.common.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import javax.validation.Constraint;
import javax.validation.Payload;

import com.chelvc.framework.common.util.StringUtils;
import com.chelvc.framework.common.validator.StringValidator;

/**
 * 字符串参数校验注解
 *
 * @author Woody
 * @date 2024/4/27
 */
@Documented
@Retention(RetentionPolicy.RUNTIME)
@Constraint(validatedBy = StringValidator.class)
@Target({ElementType.FIELD, ElementType.PARAMETER})
public @interface Strings {
    /**
     * 获取最小长度，当值>0时生效
     *
     * @return 字符串长度
     */
    int min() default -1;

    /**
     * 获取最大长度，当值>0时生效
     *
     * @return 字符串长度
     */
    int max() default -1;

    /**
     * 获取正则表达式
     *
     * @return 正则表达式
     */
    String regex() default StringUtils.EMPTY;

    /**
     * 获取异常消息
     *
     * @return 异常消息
     */
    String message() default "Invalid string";

    /**
     * 获取对象分组（固定写法）
     *
     * @return 对象数组
     */
    Class<?>[] groups() default {};

    /**
     * 获取载体对象（固定写法）
     *
     * @return 载体对象数组
     */
    Class<? extends Payload>[] payload() default {};
}
