package com.chelvc.framework.common.jackson;

import java.io.IOException;
import java.math.BigDecimal;

import com.chelvc.framework.common.annotation.Decimal;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.BeanProperty;
import com.fasterxml.jackson.databind.JsonSerializer;
import com.fasterxml.jackson.databind.SerializerProvider;
import com.fasterxml.jackson.databind.ser.ContextualSerializer;
import com.fasterxml.jackson.databind.ser.std.StdSerializer;

/**
 * JSON小数序列化处理器
 *
 * @author Woody
 * @date 2024/1/30
 */
public class JacksonDecimalSerializer extends StdSerializer<Number> implements ContextualSerializer {
    private Decimal annotation;

    public JacksonDecimalSerializer() {
        super(Number.class);
    }

    @Override
    public void serialize(Number number, JsonGenerator generator, SerializerProvider provider)
            throws IOException {
        if (this.annotation == null) {
            generator.writeObject(number);
        } else {
            BigDecimal decimal = number instanceof BigDecimal ? (BigDecimal) number : new BigDecimal(number.toString());
            decimal = decimal.setScale(this.annotation.scale(), this.annotation.mode());
            if (this.annotation.trimZeros()) {
                decimal = decimal.stripTrailingZeros();
            }
            generator.writeNumber(decimal.toPlainString());
        }
    }

    @Override
    public JsonSerializer<?> createContextual(SerializerProvider provider, BeanProperty property) {
        this.annotation = property.getAnnotation(Decimal.class);
        return this;
    }
}
