package com.chelvc.framework.common.model;

import java.io.Serializable;
import java.util.Objects;

import lombok.Data;

/**
 * 多部分对象
 *
 * @author Woody
 * @date 2025/3/15
 */
@Data
public class BiPair<L, M, R> implements Serializable {
    private L left;
    private M middle;
    private R right;

    public BiPair() {
        this(null, null, null);
    }

    public BiPair(L left, M middle, R right) {
        this.left = left;
        this.middle = middle;
        this.right = right;
    }

    @Override
    public int hashCode() {
        return Objects.hash(this.left, this.middle, this.right);
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == this) {
            return true;
        } else if (!(obj instanceof BiPair)) {
            return false;
        }
        BiPair<?, ?, ?> other = (BiPair<?, ?, ?>) obj;
        return Objects.equals(this.left, other.getLeft()) && Objects.equals(this.middle, other.getMiddle())
                && Objects.equals(this.right, other.getRight());
    }

    @Override
    public String toString() {
        return "(" + this.left + "," + this.middle + "," + this.right + ")";
    }

    /**
     * 构建多部分对象实例
     *
     * @param left   左边部分
     * @param middle 中间部分
     * @param right  右边部分
     * @param <L>    左边类型
     * @param <M>    中间类型
     * @param <R>    右边类型
     * @return 多部分对象实例
     */
    public static <L, M, R> BiPair<L, M, R> of(L left, M middle, R right) {
        return new BiPair<>(left, middle, right);
    }
}
