package com.chelvc.framework.common.model;

import java.io.Serializable;
import java.util.concurrent.Delayed;
import java.util.concurrent.TimeUnit;

import lombok.Getter;
import lombok.ToString;

/**
 * 延迟消息实体
 *
 * @param <T> 消息体类型
 * @author Woody
 * @date 2024/1/30
 */
@Getter
@ToString
public class Delayer<T> implements Delayed, Serializable {
    /**
     * 消息体对象
     */
    private final T payload;

    /**
     * 过期时间戳
     */
    private final long expiration;

    public Delayer(T payload, long expiration) {
        this.payload = payload;
        this.expiration = expiration;
    }

    @Override
    public long getDelay(TimeUnit unit) {
        return unit.convert(this.expiration - System.currentTimeMillis(), TimeUnit.NANOSECONDS);
    }

    @Override
    public int compareTo(Delayed o) {
        return (int) (this.expiration - ((Delayer<?>) o).expiration);
    }
}
