package com.chelvc.framework.common.model;

import java.io.Serializable;
import java.util.Collections;
import java.util.List;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.NonNull;
import lombok.experimental.SuperBuilder;

/**
 * 数据滚动列表信息
 *
 * @param <T> 数据类型
 * @author Woody
 * @date 2024/11/12
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
public class Scrolling<T> implements Serializable {
    /**
     * 空滚动信息
     */
    private static final Scrolling<?> EMPTY = Scrolling.builder().build();

    /**
     * 滚动标识
     */
    private String id;

    /**
     * 数据总量
     */
    @Builder.Default
    private Long total = 0L;

    /**
     * 对象列表
     */
    @Builder.Default
    private List<T> objects = Collections.emptyList();

    /**
     * 获取空滚动信息
     *
     * @param <T> 对象类型
     * @return 滚动信息
     */
    @SuppressWarnings("unchecked")
    public static <T> Scrolling<T> empty() {
        return (Scrolling<T>) EMPTY;
    }

    /**
     * 构建数据滚动信息
     *
     * @param id      滚动标识
     * @param total   数据总量
     * @param objects 数据列表
     * @param <T>     对象类型
     * @return 滚动信息
     */
    public static <T> Scrolling<T> of(@NonNull String id, long total, @NonNull List<T> objects) {
        return new Scrolling<T>(id, total, objects);
    }
}
