package com.chelvc.framework.common.model;

import java.io.Serializable;
import java.util.List;

import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

/**
 * 树形对象接口
 *
 * @param <T> 主键类型
 * @param <M> 子节点类型
 * @author Woody
 * @date 2024/1/30
 */
public interface Tree<T extends Serializable, M extends Tree<T, M>> extends Serializable {
    /**
     * 获取主键
     *
     * @return 主键
     */
    T getId();

    /**
     * 设置主键
     *
     * @param id 主键
     */
    void setId(T id);

    /**
     * 获取名称
     *
     * @return 名称
     */
    String getName();

    /**
     * 设置名称
     *
     * @param name 名称
     */
    void setName(String name);

    /**
     * 获取上级主键
     *
     * @return 主键
     */
    T getParentId();

    /**
     * 设置上级主键
     *
     * @param parentId 上级主键
     */
    void setParentId(T parentId);

    /**
     * 获取子节点列表
     *
     * @return 子节点列表
     */
    List<M> getChildren();

    /**
     * 设置子节点列表
     *
     * @param children 子节点列表
     */
    void setChildren(List<M> children);

    /**
     * 树形接口简单实现
     *
     * @param <T> 主键类型
     * @param <M> 子节点类型
     */
    @Data
    @SuperBuilder
    @NoArgsConstructor
    @AllArgsConstructor
    class Simple<T extends Serializable, M extends Simple<T, M>> implements Tree<T, M> {
        /**
         * 主键
         */
        private T id;

        /**
         * 上级主键
         */
        private T parentId;

        /**
         * 节点名称
         */
        private String name;

        /**
         * 子节点列表
         */
        private List<M> children;
    }

    /**
     * 默认树实现
     */
    class Default extends Simple<Long, Default> {
    }
}
