package com.chelvc.framework.common.validator;

import java.util.Collection;
import javax.validation.ConstraintValidator;
import javax.validation.ConstraintValidatorContext;

import com.chelvc.framework.common.annotation.Numbers;

/**
 * 数字参数验证器
 *
 * @author Woody
 * @date 2024/4/27
 */
public class NumberValidator implements ConstraintValidator<Numbers, Object> {
    private Numbers annotation;

    /**
     * 校验数字参数
     *
     * @param value 参数值
     * @return true/false
     */
    private boolean validate(Object value) {
        if (!(value instanceof Number)) {
            return true;
        }
        double number = ((Number) value).doubleValue();
        double min = this.annotation.min(), max = this.annotation.max();
        return (min < 1 || number >= min) && (max < 1 || number <= max);
    }

    @Override
    public void initialize(Numbers annotation) {
        this.annotation = annotation;
    }

    @Override
    public boolean isValid(Object value, ConstraintValidatorContext context) {
        if (this.annotation == null || (this.annotation.min() < 1 && this.annotation.max() < 1)) {
            return true;
        } else if (value instanceof Collection) {
            return ((Collection<?>) value).stream().allMatch(this::validate);
        }
        return this.validate(value);
    }
}
