package com.chelvc.framework.common.validator;

import java.util.Collection;
import javax.validation.ConstraintValidator;
import javax.validation.ConstraintValidatorContext;

import com.chelvc.framework.common.annotation.Pages;
import com.chelvc.framework.common.model.Paging;

/**
 * 分页参数验证器
 *
 * @author Woody
 * @date 2024/4/27
 */
public class PagingValidator implements ConstraintValidator<Pages, Object> {
    private Pages annotation;

    /**
     * 校验分页参数
     *
     * @param value 参数值
     * @return true/false
     */
    private boolean validate(Object value) {
        if (!(value instanceof Paging)) {
            return true;
        }
        Paging paging = (Paging) value;
        int size = this.annotation.size(), total = this.annotation.total();
        return (size < 1 || paging.getSize() <= size) && (total < 1 || paging.getNumber() * paging.getSize() <= total);
    }

    @Override
    public void initialize(Pages annotation) {
        this.annotation = annotation;
    }

    @Override
    public boolean isValid(Object value, ConstraintValidatorContext context) {
        if (this.annotation == null || (this.annotation.size() < 1 && this.annotation.total() < 1)) {
            return true;
        } else if (value instanceof Collection) {
            return ((Collection<?>) value).stream().allMatch(this::validate);
        }
        return this.validate(value);
    }
}
