package com.chelvc.framework.common.validator;

import java.util.Collection;
import javax.validation.ConstraintValidator;
import javax.validation.ConstraintValidatorContext;

import com.chelvc.framework.common.annotation.Strings;
import com.chelvc.framework.common.util.StringUtils;

/**
 * 字符串参数验证器
 *
 * @author Woody
 * @date 2024/4/27
 */
public class StringValidator implements ConstraintValidator<Strings, Object> {
    private Strings annotation;

    /**
     * 校验字符串参数
     *
     * @param value 参数值
     * @return true/false
     */
    private boolean validate(Object value) {
        if (!(value instanceof CharSequence)) {
            return true;
        }
        CharSequence source = (CharSequence) value;
        String regex = this.annotation.regex();
        int min = this.annotation.min(), max = this.annotation.max();
        return (StringUtils.isEmpty(regex) || StringUtils.matches(source, regex))
                && (min < 1 || source.length() >= min) && (max < 1 || source.length() <= max);
    }

    @Override
    public void initialize(Strings annotation) {
        this.annotation = annotation;
    }

    @Override
    public boolean isValid(Object value, ConstraintValidatorContext context) {
        if (this.annotation == null || (StringUtils.isEmpty(this.annotation.regex())
                && this.annotation.min() < 1 && this.annotation.max() < 1)) {
            return true;
        } else if (value instanceof Collection) {
            return ((Collection<?>) value).stream().allMatch(this::validate);
        }
        return this.validate(value);
    }
}
