package com.chelvc.framework.database.config;

import lombok.Data;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Configuration;

/**
 * 数据库配置属性
 *
 * @author Woody
 * @date 2024/1/30
 */
@Data
@Configuration
@ConfigurationProperties("database")
public class DatabaseProperties {
    /**
     * 加解密配置
     */
    private final Crypto crypto = new Crypto();

    /**
     * 缓存配置
     */
    @Data
    public static class Cache {
        /**
         * 缓存容量
         */
        private int capacity = 100;

        /**
         * 缓存时间（秒）
         */
        private int duration = 60;

        /**
         * 是否启用缓存
         */
        private boolean enabled = false;
    }

    /**
     * 加解密配置
     */
    @Data
    public static class Crypto {
        /**
         * 加解密密钥
         */
        private String secret;

        /**
         * 是否混合读取（同时包含明文、密文）
         */
        private boolean mixed = false;

        /**
         * 是否可写入密文
         */
        private boolean writable = true;

        /**
         * 加解密缓存配置
         */
        private final Cache cache = new Cache();
    }
}
