package com.chelvc.framework.database.context;

import java.util.function.Supplier;

import com.chelvc.framework.common.function.Executor;
import com.chelvc.framework.common.function.Handler;
import com.chelvc.framework.common.function.Provider;

/**
 * 事务处理器
 *
 * @author Woody
 * @date 2024/1/30
 */
public interface Transactor {
    /**
     * 事务执行
     *
     * @param executor 事务方法接口
     */
    void execute(Executor executor);

    /**
     * 事务执行
     *
     * @param executor 事务方法接口
     * @param <T>      对象类型
     * @return 执行结果
     */
    <T> T execute(Supplier<T> executor);

    /**
     * 事务执行
     *
     * @param executor 事务方法接口
     * @throws Exception 操作异常
     */
    void execute(Handler executor) throws Exception;

    /**
     * 事务执行
     *
     * @param executor 事务方法接口
     * @param <T>      对象类型
     * @return 执行结果
     * @throws Exception 操作异常
     */
    <T> T execute(Provider<T> executor) throws Exception;
}
