package com.chelvc.framework.database.handler;

import java.sql.CallableStatement;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

import com.chelvc.framework.database.context.DatabaseContextHolder;
import org.apache.ibatis.type.JdbcType;

/**
 * 敏感字符串数组字段处理实现
 *
 * @author Woody
 * @date 2024/6/18
 */
public class SensitiveArrayTypeHandler extends JsonTypeHandler.Default<String[]> {
    @Override
    public void setNonNullParameter(PreparedStatement ps, int i, String[] parameter, JdbcType jdbcType)
            throws SQLException {
        if (DatabaseContextHolder.getDatabaseCipherHandler().isWritable()) {
            parameter = DatabaseContextHolder.getDatabaseCipherHandler().encrypt(parameter, true);
        }
        super.setNonNullParameter(ps, i, parameter, jdbcType);
    }

    @Override
    public String[] getNullableResult(ResultSet rs, String columnName) throws SQLException {
        String[] values = super.getNullableResult(rs, columnName);
        return DatabaseContextHolder.getDatabaseCipherHandler().decrypt(values, true);
    }

    @Override
    public String[] getNullableResult(ResultSet rs, int columnIndex) throws SQLException {
        String[] values = super.getNullableResult(rs, columnIndex);
        return DatabaseContextHolder.getDatabaseCipherHandler().decrypt(values, true);
    }

    @Override
    public String[] getNullableResult(CallableStatement cs, int columnIndex) throws SQLException {
        String[] values = super.getNullableResult(cs, columnIndex);
        return DatabaseContextHolder.getDatabaseCipherHandler().decrypt(values, true);
    }
}
