package com.chelvc.framework.database.handler;

import java.sql.CallableStatement;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

import com.chelvc.framework.database.context.DatabaseContextHolder;
import org.apache.ibatis.type.BaseTypeHandler;
import org.apache.ibatis.type.JdbcType;

/**
 * 敏感字段类型处理实现
 *
 * @author Woody
 * @date 2024/6/7
 */
public class SensitiveTypeHandler extends BaseTypeHandler<String> {
    @Override
    public void setNonNullParameter(PreparedStatement ps, int i, String parameter, JdbcType jdbcType)
            throws SQLException {
        if (DatabaseContextHolder.getDatabaseCipherHandler().isWritable()) {
            parameter = DatabaseContextHolder.getDatabaseCipherHandler().encrypt(parameter, true);
        }
        ps.setString(i, parameter);
    }

    @Override
    public String getNullableResult(ResultSet rs, String columnName) throws SQLException {
        String value = rs.getString(columnName);
        return DatabaseContextHolder.getDatabaseCipherHandler().decrypt(value, true);
    }

    @Override
    public String getNullableResult(ResultSet rs, int columnIndex) throws SQLException {
        String value = rs.getString(columnIndex);
        return DatabaseContextHolder.getDatabaseCipherHandler().decrypt(value, true);
    }

    @Override
    public String getNullableResult(CallableStatement cs, int columnIndex) throws SQLException {
        String value = cs.getString(columnIndex);
        return DatabaseContextHolder.getDatabaseCipherHandler().decrypt(value, true);
    }
}
