package com.chelvc.framework.database.interceptor;

import com.baomidou.mybatisplus.extension.plugins.MybatisPlusInterceptor;
import com.baomidou.mybatisplus.extension.plugins.inner.InnerInterceptor;
import com.baomidou.mybatisplus.extension.plugins.inner.PaginationInnerInterceptor;
import com.baomidou.mybatisplus.extension.plugins.inner.TenantLineInnerInterceptor;
import com.chelvc.framework.base.context.ApplicationContextHolder;
import lombok.NonNull;
import org.apache.ibatis.executor.Executor;
import org.apache.ibatis.plugin.Invocation;
import org.springframework.context.ApplicationContext;

/**
 * 自定义MybatisPlus拦截器
 *
 * @author Woody
 * @date 2025/3/16
 */
public abstract class CustomizeMybatisPlusInterceptor extends MybatisPlusInterceptor {
    public CustomizeMybatisPlusInterceptor(@NonNull ApplicationContext applicationContext) {
        // 设置自定义租户隔离拦截器
        ApplicationContextHolder.getSortBeans(applicationContext, InnerInterceptor.class)
                .forEach(this::addInnerInterceptor);

        // 设置数据环境隔离过滤拦截器
        this.addInnerInterceptor(new TenantLineInnerInterceptor() {
            {
                this.setTenantLineHandler(new EnvIsolateInterceptor());
            }
        });

        // 设置数据逻辑删除过滤拦截器
        this.addInnerInterceptor(new TenantLineInnerInterceptor() {
            {
                this.setTenantLineHandler(new DeletedIsolateInterceptor());
            }
        });

        // 设置分页拦截器，数据过滤条件与拦截器设置顺序有关，分页拦截器最后设置才能在分页时同时使用数据隔离过滤条件
        this.addInnerInterceptor(new PaginationInnerInterceptor());
    }

    /**
     * 获取SQL执行上下文
     *
     * @return 上下文对象实例
     */
    protected abstract Tables.Context getContext();

    @Override
    public Object intercept(Invocation invocation) throws Throwable {
        if (invocation.getTarget() instanceof Executor) {
            Tables.setContext(this.getContext());
            try {
                return super.intercept(invocation);
            } finally {
                Tables.removeContext();
            }
        }
        return super.intercept(invocation);
    }
}
