package com.chelvc.framework.database.interceptor;

import java.sql.Connection;
import javax.sql.DataSource;

import com.chelvc.framework.database.util.SQLUtils;
import com.zaxxer.hikari.HikariDataSource;
import lombok.NonNull;
import org.apache.ibatis.cache.CacheKey;
import org.apache.ibatis.executor.Executor;
import org.apache.ibatis.executor.statement.StatementHandler;
import org.apache.ibatis.mapping.BoundSql;
import org.apache.ibatis.mapping.MappedStatement;
import org.apache.ibatis.plugin.Intercepts;
import org.apache.ibatis.plugin.Signature;
import org.apache.ibatis.session.ResultHandler;
import org.apache.ibatis.session.RowBounds;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingClass;
import org.springframework.context.ApplicationContext;
import org.springframework.stereotype.Component;

/**
 * 普通数据源MybatisPlus拦截器
 *
 * @author Woody
 * @date 2025/3/17
 */
@Component
@Intercepts({
        @Signature(type = StatementHandler.class, method = "getBoundSql", args = {}),
        @Signature(type = StatementHandler.class, method = "prepare", args = {Connection.class, Integer.class}),
        @Signature(type = Executor.class, method = "update", args = {MappedStatement.class, Object.class}),
        @Signature(
                type = Executor.class, method = "query",
                args = {MappedStatement.class, Object.class, RowBounds.class, ResultHandler.class}
        ),
        @Signature(
                type = Executor.class, method = "query",
                args = {
                        MappedStatement.class, Object.class, RowBounds.class,
                        ResultHandler.class, CacheKey.class, BoundSql.class
                }
        )
})
@ConditionalOnMissingClass(
        "com.baomidou.dynamic.datasource.spring.boot.autoconfigure.DynamicDataSourceAutoConfiguration"
)
public class NormalDataSourceMybatisPlusInterceptor extends CustomizeMybatisPlusInterceptor {
    private final String schema;

    public NormalDataSourceMybatisPlusInterceptor(@NonNull ApplicationContext applicationContext) {
        super(applicationContext);

        DataSource dataSource = applicationContext.getBean(DataSource.class);
        if (dataSource instanceof HikariDataSource) {
            this.schema = SQLUtils.getSchema(((HikariDataSource) dataSource).getJdbcUrl());
        } else {
            throw new RuntimeException("Unknown datasource: " + dataSource);
        }
    }

    @Override
    protected Tables.Context getContext() {
        return new Tables.Context(this.schema, null);
    }
}
