package com.chelvc.framework.database.sql;

import java.sql.CallableStatement;
import java.sql.SQLException;
import java.util.Map;

import com.chelvc.framework.database.context.DatabaseContextHolder;

/**
 * CallableStatement字符串读取解密处理器
 *
 * @author Woody
 * @date 2024/6/8
 */
public class CallableStringDecrypter extends CallableStatementWrapper {
    public CallableStringDecrypter(CallableStatement delegate) {
        super(delegate);
    }

    /**
     * 数据处理
     *
     * @param original 原始数据
     * @param <T>      数据类型
     * @return 结果数据
     */
    @SuppressWarnings("unchecked")
    private <T> T handle(T original) {
        if (original instanceof String) {
            // 字符串数据解密
            return (T) DatabaseContextHolder.getDatabaseCipherHandler().decrypt((String) original, true);
        }
        return original;
    }

    @Override
    public Object getObject(int parameterIndex) throws SQLException {
        return this.handle(super.getObject(parameterIndex));
    }

    @Override
    public Object getObject(int parameterIndex, Map<String, Class<?>> map) throws SQLException {
        return this.handle(super.getObject(parameterIndex, map));
    }

    @Override
    public Object getObject(String parameterName) throws SQLException {
        return this.handle(super.getObject(parameterName));
    }

    @Override
    public Object getObject(String parameterName, Map<String, Class<?>> map) throws SQLException {
        return this.handle(super.getObject(parameterName, map));
    }

    @Override
    public <T> T getObject(int parameterIndex, Class<T> type) throws SQLException {
        return this.handle(super.getObject(parameterIndex, type));
    }

    @Override
    public <T> T getObject(String parameterName, Class<T> type) throws SQLException {
        return this.handle(super.getObject(parameterName, type));
    }

    @Override
    public String getString(int parameterIndex) throws SQLException {
        return this.handle(super.getString(parameterIndex));
    }

    @Override
    public String getString(String parameterName) throws SQLException {
        return this.handle(super.getString(parameterName));
    }
}
