package com.chelvc.framework.database.sql;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Map;

import com.chelvc.framework.database.context.DatabaseContextHolder;

/**
 * ResultSet字符串读取解密处理器
 *
 * @author Woody
 * @date 2024/6/8
 */
public class ResultStringDecrypter extends ResultSetWrapper {
    public ResultStringDecrypter(ResultSet delegate) {
        super(delegate);
    }

    /**
     * 数据处理
     *
     * @param original 原始数据
     * @param <T>      数据类型
     * @return 结果数据
     */
    @SuppressWarnings("unchecked")
    private <T> T handle(T original) {
        if (original instanceof String) {
            // 字符串数据解密
            return (T) DatabaseContextHolder.getDatabaseCipherHandler().decrypt((String) original, true);
        }
        return original;
    }

    @Override
    public Object getObject(int columnIndex) throws SQLException {
        return this.handle(super.getObject(columnIndex));
    }

    @Override
    public Object getObject(String columnLabel) throws SQLException {
        return this.handle(super.getObject(columnLabel));
    }

    @Override
    public Object getObject(int columnIndex, Map<String, Class<?>> map) throws SQLException {
        return this.handle(super.getObject(columnIndex, map));
    }

    @Override
    public Object getObject(String columnLabel, Map<String, Class<?>> map) throws SQLException {
        return this.handle(super.getObject(columnLabel, map));
    }

    @Override
    public <T> T getObject(int columnIndex, Class<T> type) throws SQLException {
        return this.handle(super.getObject(columnIndex, type));
    }

    @Override
    public <T> T getObject(String columnLabel, Class<T> type) throws SQLException {
        return this.handle(super.getObject(columnLabel, type));
    }

    @Override
    public String getString(int columnIndex) throws SQLException {
        return this.handle(super.getString(columnIndex));
    }

    @Override
    public String getString(String columnLabel) throws SQLException {
        return this.handle(super.getString(columnLabel));
    }
}
