package com.chelvc.framework.database.support;

import java.util.Collection;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Param;

/**
 * 数据模型增强操作接口，忽略字段验证策略配置
 *
 * @author Woody
 * @date 2024/4/3
 */
public interface EnhanceMapper<T> extends BaseMapper<T> {
    /**
     * 创建或忽略实体
     *
     * @param entity 实体对象实例
     * @return 影响行数
     */
    int createIgnore(T entity);

    /**
     * 创建或修改实体
     *
     * @param entity 实体对象实例
     * @param update 数据更新对象实例
     * @return 影响行数
     */
    int createUpdate(@Param("et") T entity, @Param("update") Updates.Update<T> update);

    /**
     * 批量创建或忽略实体
     *
     * @param entities 实体对象实例集合
     * @return 影响行数
     */
    int batchCreateIgnore(Collection<T> entities);

    /**
     * 批量创建或修改实体
     *
     * @param entities 实体对象实例集合
     * @param update   数据更新对象实例
     * @return 影响行数
     */
    int batchCreateUpdate(@Param("coll") Collection<T> entities, @Param("update") Updates.Update<T> update);
}
