package com.chelvc.framework.elasticsearch.config;

import co.elastic.clients.json.jackson.JacksonJsonpMapper;
import co.elastic.clients.transport.ElasticsearchTransport;
import co.elastic.clients.transport.rest_client.RestClientTransport;
import com.chelvc.framework.common.util.JacksonUtils;
import com.chelvc.framework.common.util.StringUtils;
import com.chelvc.framework.elasticsearch.DefaultElasticsearchHandler;
import com.chelvc.framework.elasticsearch.ElasticsearchHandler;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.apache.http.HttpHost;
import org.apache.http.auth.AuthScope;
import org.apache.http.auth.UsernamePasswordCredentials;
import org.apache.http.client.CredentialsProvider;
import org.apache.http.impl.client.BasicCredentialsProvider;
import org.elasticsearch.client.RestClient;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

/**
 * ES配置
 *
 * @author Woody
 * @date 2024/10/17
 */
@Configuration
public class ElasticsearchConfigurer {
    @Bean(destroyMethod = "close")
    public ElasticsearchTransport elasticsearchTransport(ElasticsearchProperties properties) {
        HttpHost host = new HttpHost(properties.getHost(), properties.getPort(), properties.getScheme());
        RestClient client = RestClient.builder(host).setHttpClientConfigCallback(builder -> {
            if (properties.getMaxConnTotal() > 0) {
                builder.setMaxConnTotal(properties.getMaxConnTotal());
            }
            if (properties.getMaxConnPerRoute() > 0) {
                builder.setMaxConnPerRoute(properties.getMaxConnPerRoute());
            }
            if (StringUtils.notEmpty(properties.getUsername()) && StringUtils.notEmpty(properties.getPassword())) {
                UsernamePasswordCredentials credentials =
                        new UsernamePasswordCredentials(properties.getUsername(), properties.getPassword());
                CredentialsProvider credentialsProvider = new BasicCredentialsProvider();
                credentialsProvider.setCredentials(AuthScope.ANY, credentials);
                builder.setDefaultCredentialsProvider(credentialsProvider);
            }
            return builder;
        }).build();
        ObjectMapper mapper = JacksonUtils.configure(new ObjectMapper());
        return new RestClientTransport(client, new JacksonJsonpMapper(mapper));
    }

    @Bean
    @ConditionalOnMissingBean(ElasticsearchHandler.class)
    public ElasticsearchHandler elasticsearchHandler(ElasticsearchTransport transport) {
        return new DefaultElasticsearchHandler(transport);
    }
}
