package com.chelvc.framework.feign.circuitbreaker;

import com.chelvc.framework.base.context.ApplicationContextHolder;
import com.chelvc.framework.common.exception.FrameworkException;
import io.github.resilience4j.circuitbreaker.CircuitBreaker;
import io.github.resilience4j.circuitbreaker.configure.CircuitBreakerAspectExt;
import io.github.resilience4j.fallback.DefaultFallbackDecorator;
import io.github.resilience4j.fallback.FallbackMethod;
import io.github.resilience4j.timelimiter.configure.IllegalReturnTypeException;
import io.vavr.CheckedFunction0;
import org.aspectj.lang.ProceedingJoinPoint;
import org.springframework.stereotype.Component;

/**
 * 熔断降级处理拦截器
 *
 * @author Woody
 * @date 2025/4/15
 */
@Component
public class CircuitBreakerInterceptor extends DefaultFallbackDecorator implements CircuitBreakerAspectExt {
    @Override
    public boolean canHandleReturnType(Class returnType) {
        return true;
    }

    @Override
    public CheckedFunction0<Object> decorate(FallbackMethod fallbackMethod, CheckedFunction0<Object> supplier) {
        return () -> {
            try {
                return supplier.apply();
            } catch (IllegalReturnTypeException | FrameworkException e) {
                throw e;
            } catch (Throwable t) {
                return fallbackMethod.fallback(t);
            }
        };
    }

    @Override
    public Object handle(ProceedingJoinPoint point, CircuitBreaker circuitBreaker, String method) throws Throwable {
        boolean enabled = ApplicationContextHolder.getProperty("circuit.breaker.enabled", boolean.class, true);
        if (enabled) {
            return circuitBreaker.executeCheckedSupplier(point::proceed);
        }
        return point.proceed();
    }
}
