package com.chelvc.framework.feign.encoder;

import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.Date;
import java.util.Map;

import com.chelvc.framework.common.util.DateUtils;
import com.chelvc.framework.common.util.ObjectUtils;
import feign.codec.EncodeException;
import feign.querymap.FieldQueryMapEncoder;

/**
 * 自定义查询参数编码处理器
 *
 * @author Woody
 * @date 2024/10/30
 */
public class CustomizeQueryEncoder extends FieldQueryMapEncoder {
    @Override
    public Map<String, Object> encode(Object object) throws EncodeException {
        Map<String, Object> queries = super.encode(object);
        if (ObjectUtils.notEmpty(queries)) {
            for (Map.Entry<String, Object> entry : queries.entrySet()) {
                Object value = entry.getValue();
                if (value instanceof Date) {
                    entry.setValue(((Date) value).getTime());
                } else if (value instanceof LocalDate) {
                    entry.setValue(DateUtils.convert((LocalDate) value).getTime());
                } else if (value instanceof LocalDateTime) {
                    entry.setValue(DateUtils.convert((LocalDateTime) value).getTime());
                }
            }
        }
        return queries;
    }
}
