package com.chelvc.framework.feign.interceptor;

import java.io.BufferedReader;
import java.io.IOException;
import java.nio.charset.StandardCharsets;

import com.chelvc.framework.base.context.Result;
import com.chelvc.framework.common.exception.FrameworkException;
import com.chelvc.framework.common.util.JacksonUtils;
import com.chelvc.framework.common.util.StringUtils;
import feign.Response;
import feign.codec.ErrorDecoder;

/**
 * Feign调用失败处理拦截器
 *
 * @author Woody
 * @date 2024/1/30
 */
public class FeignFailureInterceptor implements ErrorDecoder {
    /**
     * 反序列化请求结果
     *
     * @param body 消息体内容
     * @return 请求结果
     */
    protected Result<?> deserialize(String body) {
        return JacksonUtils.deserialize(body, Result.class);
    }

    @Override
    public Exception decode(String method, Response response) {
        String body;
        try (BufferedReader reader = new BufferedReader(response.body().asReader(StandardCharsets.UTF_8))) {
            body = reader.readLine();
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        Result<?> result = StringUtils.isEmpty(body) ? Result.failure() : this.deserialize(body);
        return new FrameworkException(result.getCode(), result.getData(), result.getMessage());
    }
}
