package com.chelvc.framework.group;

import java.util.Map;

import com.chelvc.framework.base.context.ApplicationContextHolder;
import com.chelvc.framework.common.util.ObjectUtils;
import com.google.common.collect.Maps;
import lombok.NonNull;
import org.springframework.context.ApplicationContext;

/**
 * 分组处理器工厂默认实现
 *
 * @author Woody
 * @date 2025/4/7
 */
public class DefaultGroupHandlerFactory implements GroupHandlerFactory {
    private final ApplicationContext applicationContext;
    private final Map<Class<?>, GroupHandler> handlers = Maps.newConcurrentMap();

    public DefaultGroupHandlerFactory(@NonNull ApplicationContext applicationContext) {
        this.applicationContext = applicationContext;
    }

    @Override
    @SuppressWarnings("unchecked")
    public <T extends GroupHandler> T getHandler(@NonNull Class<T> type) {
        T handler = ApplicationContextHolder.getBean(this.applicationContext, type, false);
        if (handler == null && (handler = (T) this.handlers.get(type)) == null) {
            handler = (T) this.handlers.computeIfAbsent(type, k -> ObjectUtils.instance(type));
        }
        return handler;
    }
}
