package com.chelvc.framework.group.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import com.chelvc.framework.base.annotation.Version;
import com.chelvc.framework.common.model.Invoking;
import com.chelvc.framework.common.model.Platform;
import com.chelvc.framework.common.model.Terminal;
import com.chelvc.framework.group.GroupHandler;
import com.chelvc.framework.group.SimpleGroupHandler;

/**
 * 场景分组注解
 *
 * @author Woody
 * @date 2024/9/8
 */
@Documented
@Target({})
@Retention(RetentionPolicy.RUNTIME)
public @interface Group {
    /**
     * 获取分组场景
     *
     * @return 分组场景
     */
    String scene();

    /**
     * 是否异步分组
     *
     * @return true/false
     */
    boolean async() default false;

    /**
     * 获取渠道数组
     *
     * @return 渠道数组
     */
    String[] channels() default {};

    /**
     * 获取版本数组
     *
     * @return 版本数组
     */
    Version[] versions() default {};

    /**
     * 获取平台数组
     *
     * @return 平台数组
     */
    Platform[] platforms() default {};

    /**
     * 获取终端数组
     *
     * @return 终端数组
     */
    Terminal[] terminals() default {};

    /**
     * 获取分组时机
     *
     * @return 分组时机
     */
    Invoking invoking() default Invoking.REQUEST;

    /**
     * 获取分组处理器
     *
     * @return 分组处理器对象
     */
    Class<? extends GroupHandler> handler() default SimpleGroupHandler.class;
}
