package com.chelvc.framework.jpush;

import java.io.Serializable;
import java.util.List;
import java.util.Map;

import com.fasterxml.jackson.annotation.JsonAlias;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

/**
 * 聊天消息
 *
 * @author Woody
 * @date 2024/1/30
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
public class ChatMessage implements Serializable {
    /**
     * 消息总量
     */
    private Long total;

    /**
     * 当前消息数量
     */
    private Long count;

    /**
     * 剩余消息记录状态码（如果返回该字段有值，则表示还有消息待拉取）
     */
    private String cursor;

    /**
     * 消息列表
     */
    private List<Message> messages;

    @Data
    @SuperBuilder
    @NoArgsConstructor
    @AllArgsConstructor
    public static class Message implements Serializable {
        /**
         * 目标类型
         */
        @JsonAlias("target_type")
        private String targetType;

        /**
         * 消息类型
         */
        @JsonAlias("msg_type")
        private String msgType;

        /**
         * 目标名称
         */
        @JsonAlias("target_name")
        private String targetName;

        /**
         * 目标id
         */
        @JsonAlias("target_id")
        private String targetId;

        /**
         * 发送消息人id
         */
        @JsonAlias("from_id")
        private String fromId;

        /**
         * 发送消息人名称
         */
        @JsonAlias("from_name")
        private String fromName;

        /**
         * 发送消息人类型
         */
        @JsonAlias("from_type")
        private String fromType;

        /**
         * 发送消息人平台
         */
        @JsonAlias("from_platform")
        private String fromPlatform;

        /**
         * 消息体
         */
        @JsonAlias("msg_body")
        private Body msgBody;

        /**
         * 消息创建时间
         */
        @JsonAlias("create_time")
        private Long createTime;

        /**
         * 版本号
         */
        private Integer version;

        /**
         * 消息id
         */
        @JsonAlias("msgid")
        private Long msgId;

        /**
         * 消息登记
         */
        @JsonAlias("msg_level")
        private Integer msgLevel;

        /**
         * 消息发送时间
         */
        @JsonAlias("msg_ctime")
        private Long msgCtime;

        /**
         * 消息是否离线存储 true或者false，默认为false，表示需要离线存储（选填）
         */
        private Boolean noOffline;

        /**
         * 消息是否在通知栏展示 true或者false，默认为false，表示在通知栏展示（选填）
         */
        private Boolean noNotification;

        /**
         * 目标用户头像
         */
        private String targetAvatar;

        /**
         * 发送信息人头像
         */
        private String fromAvatar;
    }

    @Data
    @SuperBuilder
    @NoArgsConstructor
    @AllArgsConstructor
    public static class Body implements Serializable {
        /**
         * 文本消息内容
         */
        private String text;

        private Map<String, String> extras;

        @JsonAlias("media_id")
        private String mediaId;

        @JsonAlias("media_crc32")
        private Long mediaCrc32;

        private Double duration;

        private Integer width;

        private Integer height;

        private String format;

        private Integer fsize;

        private String resume;

        private String isFirst;

        private String promptInfo;

        private String position;

        private String hash;
    }
}
