package com.chelvc.framework.jpush.config;

import java.util.Comparator;

import cn.jiguang.common.ClientConfig;
import cn.jiguang.common.ServiceHelper;
import cn.jiguang.common.connection.ApacheHttpClient;
import cn.jiguang.common.resp.APIConnectionException;
import cn.jiguang.common.resp.APIRequestException;
import cn.jmessage.api.JMessageClient;
import cn.jpush.api.JPushClient;
import cn.jpush.api.push.CIDResult;
import cn.jpush.api.push.PushClient;
import com.chelvc.framework.common.util.ObjectUtils;
import com.chelvc.framework.jpush.DefaultJPushHandler;
import com.chelvc.framework.jpush.JPushHandler;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

/**
 * 极光推送配置
 *
 * @author Woody
 * @date 2024/1/30
 */
@Configuration
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class JPushConfigurer {
    private final JPushProperties properties;

    @Bean
    @ConditionalOnMissingBean(JPushClient.class)
    public JPushClient jpushClient() {
        String appid = this.properties.getAppid(), secret = this.properties.getSecret();
        return new JPushClient(secret, appid) {
            {
                ObjectUtils.setObjectValue(this, "_pushClient", new PushClient(secret, appid) {
                    @Override
                    public CIDResult getCidList(int count, String type) throws APIConnectionException,
                            APIRequestException {
                        // 对批量推送CID排序，确保推送结果顺序与发送数据顺序一致
                        CIDResult result = super.getCidList(count, type);
                        if (result != null && ObjectUtils.notEmpty(result.cidlist)) {
                            result.cidlist.sort(Comparator.naturalOrder());
                        }
                        return result;
                    }
                });
            }
        };
    }

    @Bean
    @ConditionalOnMissingBean(JMessageClient.class)
    public JMessageClient jmessageClient() {
        String appid = this.properties.getAppid(), secret = this.properties.getSecret();
        JMessageClient client = new JMessageClient(appid, secret);
        client.setHttpClient(new ApacheHttpClient(
                ServiceHelper.getBasicAuthorization(appid, secret), null, ClientConfig.getInstance()
        ));
        return client;
    }

    @Bean
    @ConditionalOnMissingBean(JPushHandler.class)
    public JPushHandler jpushHandler(JPushClient pushClient, JMessageClient messageClient) {
        return new DefaultJPushHandler(pushClient, messageClient, this.properties);
    }
}
