package com.chelvc.framework.kafka.fallback;

import com.chelvc.framework.kafka.producer.KafkaMessageSender;
import lombok.NonNull;
import lombok.extern.slf4j.Slf4j;
import org.apache.kafka.clients.producer.ProducerRecord;
import org.springframework.kafka.support.SendResult;
import org.springframework.util.concurrent.ListenableFuture;
import org.springframework.util.concurrent.SettableListenableFuture;

/**
 * Kafka消息发送降级处理器抽象实现
 *
 * @author Woody
 * @date 2024/7/23
 */
@Slf4j
public abstract class KafkaFallbackSender<K, V> implements KafkaMessageSender<K, V> {
    protected final KafkaMessageSender<K, V> delegate;

    public KafkaFallbackSender(@NonNull KafkaMessageSender<K, V> delegate) {
        this.delegate = delegate;
    }

    /**
     * 消息发送降级处理
     *
     * @param record 消息记录
     */
    protected abstract void fallback(ProducerRecord<K, V> record);

    @Override
    public ListenableFuture<SendResult<K, V>> send(ProducerRecord<K, V> record) {
        try {
            return this.delegate.send(record);
        } catch (Exception e) {
            log.error("Kafka message send failed: {}", record.topic(), e);
        }
        this.fallback(record);
        SettableListenableFuture<SendResult<K, V>> future = new SettableListenableFuture<>();
        future.set(new FallbackSendResult<K, V>(record));
        return future;
    }
}
