package com.chelvc.framework.kafka.fallback;

import com.chelvc.framework.base.context.Session;
import com.chelvc.framework.base.context.SessionContextHolder;
import com.chelvc.framework.kafka.context.KafkaContextHolder;
import com.chelvc.framework.kafka.producer.KafkaMessageSender;
import lombok.NonNull;
import lombok.extern.slf4j.Slf4j;
import org.apache.kafka.clients.producer.ProducerRecord;

/**
 * Kafka持久化降级发送处理器实现
 *
 * @param <K> 顺序标识类型
 * @param <V> 消息载体类型
 * @author Woody
 * @date 2024/12/19
 */
@Slf4j
public class KafkaPersistentSender<K, V> extends KafkaFallbackSender<K, V> {
    private final KafkaStoreClient client;

    public KafkaPersistentSender(@NonNull KafkaStoreClient client, @NonNull KafkaMessageSender<K, V> delegate) {
        super(delegate);
        this.client = client;
    }

    @Override
    protected void fallback(ProducerRecord<K, V> record) {
        if (log.isDebugEnabled()) {
            log.debug("Kafka fallback message: {}, {}", record.topic(), record.value());
        }

        KafkaFallbackMessage fallback =
                new KafkaFallbackMessage(record.topic(), record.value(), record.key(), record.partition());
        Session session = SessionContextHolder.getSession(false);
        if (session == null && (session = KafkaContextHolder.getSession(record.headers())) != null) {
            SessionContextHolder.setSession(session);
            try {
                this.client.save(fallback);
            } finally {
                SessionContextHolder.removeSessionContext();
            }
        } else {
            this.client.save(fallback);
        }
    }
}
