package com.chelvc.framework.kafka.interceptor;

import java.util.Map;

import com.chelvc.framework.base.context.SessionContextHolder;
import com.chelvc.framework.kafka.context.KafkaContextHolder;
import lombok.extern.slf4j.Slf4j;
import org.apache.kafka.clients.consumer.Consumer;
import org.apache.kafka.clients.consumer.ConsumerRecord;
import org.apache.kafka.clients.producer.ProducerInterceptor;
import org.apache.kafka.clients.producer.ProducerRecord;
import org.apache.kafka.clients.producer.RecordMetadata;
import org.springframework.kafka.listener.RecordInterceptor;

/**
 * Kafka消息会话处理拦截器
 *
 * @author Woody
 * @date 2024/1/30
 */
@Slf4j
public class KafkaSessionInterceptor implements ProducerInterceptor<Object, Object>, RecordInterceptor<Object, Object> {
    @Override
    public ProducerRecord<Object, Object> onSend(ProducerRecord<Object, Object> record) {
        // 初始化会话信息到消息头
        KafkaContextHolder.initializeSession(record.headers());

        // 隔离消息主题环境
        String topic = KafkaContextHolder.isolate(record.topic());

        // 构建新的消息生产记录
        return new ProducerRecord<>(topic, record.partition(), record.timestamp(), record.key(),
                record.value(), record.headers());
    }

    @Override
    public void onAcknowledgement(RecordMetadata metadata, Exception e) {
    }

    @Override
    public void close() {
    }

    @Override
    public void configure(Map<String, ?> map) {
    }

    @Override
    public ConsumerRecord<Object, Object> intercept(ConsumerRecord<Object, Object> record) {
        // 设置当前会话信息
        SessionContextHolder.setSession(KafkaContextHolder.getSession(record.headers()));
        return record;
    }

    @Override
    public void afterRecord(ConsumerRecord<Object, Object> record, Consumer<Object, Object> consumer) {
        // 清空当前会话
        SessionContextHolder.removeSessionContext();
    }

    @Override
    public void failure(ConsumerRecord<Object, Object> record, Exception exception, Consumer<Object, Object> consumer) {
        String topic = record.topic(), group = consumer.groupMetadata().groupId();
        log.error("Kafka message consume failed: {}:{}, {}", topic, group, record.value(), exception);
    }
}
