package com.chelvc.framework.kafka.producer;

import org.apache.kafka.clients.producer.ProducerRecord;
import org.springframework.beans.factory.DisposableBean;
import org.springframework.kafka.support.SendResult;
import org.springframework.util.concurrent.ListenableFuture;

/**
 * Kafka消息发送处理器接口
 *
 * @param <K> 顺序标识类型
 * @param <V> 消息载体类型
 * @author Woody
 * @date 2024/7/18
 */
public interface KafkaMessageSender<K, V> extends DisposableBean {
    /**
     * 发送消息
     *
     * @param record 消息记录
     * @return 发送结果
     */
    ListenableFuture<SendResult<K, V>> send(ProducerRecord<K, V> record);

    @Override
    default void destroy() throws Exception {
    }
}
