package com.chelvc.framework.kafka.producer;

import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import com.chelvc.framework.common.util.JacksonUtils;
import com.chelvc.framework.common.util.ObjectUtils;
import lombok.NonNull;
import lombok.extern.slf4j.Slf4j;

/**
 * Kafka事务消息检测器标准实现
 *
 * @author Woody
 * @date 2025/5/9
 */
@Slf4j
public class StandardTransactionChecker implements KafkaTransactionChecker {
    private final Map<String, TransactionCheckProcessor<?>> processors;

    public StandardTransactionChecker(@NonNull List<TransactionCheckProcessor<?>> processors) {
        this.processors = ObjectUtils.isEmpty(processors) ? Collections.emptyMap() :
                processors.stream().collect(Collectors.toMap(TransactionCheckProcessor::topic, processor -> processor));
    }

    @Override
    @SuppressWarnings({"unchecked", "rawtypes"})
    public TransactionResolution check(TransactionMessage message) {
        TransactionCheckProcessor processor = this.processors.get(message.getTopic());
        if (processor == null) {
            log.error("Transaction message check processor is missing: {}", message.getTopic());
            return TransactionResolution.UNKNOWN;
        }

        Object payload = JacksonUtils.convert(message.getPayload(), processor.model());
        return ObjectUtils.ifNull(processor.check(payload), TransactionResolution.UNKNOWN);
    }
}
