package com.chelvc.framework.location.config;

import com.chelvc.framework.location.LocationHandler;
import com.chelvc.framework.location.support.CacheableLocationHandler;
import com.chelvc.framework.redis.context.RedisContextHolder;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

/**
 * 地址定位缓存配置
 *
 * @author Woody
 * @date 2024/8/5
 */
@Configuration
@ConditionalOnClass(RedisContextHolder.class)
public class CacheableLocationConfigurer extends LocationConfigurer {
    @Bean
    @ConditionalOnMissingBean(LocationHandler.class)
    public LocationHandler locationHandler(LocationProperties properties) {
        LocationHandler delegating = this.getLocationHandler(properties);
        if (delegating != null && properties.getCaching().isEnabled()) {
            return new CacheableLocationHandler(delegating, properties.getCaching().getExpiration());
        }
        return delegating;
    }
}
