package com.chelvc.framework.location.config;

import java.util.List;
import java.util.stream.Collectors;

import com.chelvc.framework.common.util.ObjectUtils;
import com.chelvc.framework.location.LocationHandler;
import com.chelvc.framework.location.support.DelegatingLocationHandler;
import com.chelvc.framework.location.support.JuheLocationHandler;
import com.chelvc.framework.location.support.TencentLocationHandler;

/**
 * 地址定位配置基类
 *
 * @author Woody
 * @date 2024/1/30
 */
public abstract class LocationConfigurer {
    /**
     * 初始化地址定位处理器实例
     *
     * @param client 客户端配置
     * @return 地址定位处理器实例
     */
    protected LocationHandler initializeLocationHandler(LocationProperties.Client client) {
        LocationProperties.Channel channel = client.getChannel();
        if (channel == LocationProperties.Channel.JUHE) {
            return new JuheLocationHandler(client.getKey());
        } else if (channel == LocationProperties.Channel.TENCENT) {
            return new TencentLocationHandler(client.getKey());
        }
        throw new UnsupportedOperationException(String.valueOf(channel));
    }

    /**
     * 获取地址定位处理器
     *
     * @param properties 配置属性
     * @return 地址定位处理器实例
     */
    protected LocationHandler getLocationHandler(LocationProperties properties) {
        List<LocationHandler> handlers = properties.getClients().stream().map(this::initializeLocationHandler)
                .collect(Collectors.toList());
        return ObjectUtils.isEmpty(handlers) ? null : new DelegatingLocationHandler(handlers);
    }
}
