package com.chelvc.framework.location.config;

import java.util.Collections;
import java.util.List;

import lombok.Data;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Configuration;

/**
 * 地址定位配置属性
 *
 * @author Woody
 * @date 2024/1/30
 */
@Data
@Configuration
@ConfigurationProperties("location")
public class LocationProperties {
    /**
     * 缓存配置
     */
    private final Caching caching = new Caching();

    /**
     * 地址定位客户端配置
     */
    private List<Client> clients = Collections.emptyList();

    /**
     * 地址定位渠道枚举
     */
    public enum Channel {
        /**
         * 聚合数据
         */
        JUHE,

        /**
         * 腾讯云
         */
        TENCENT;
    }

    /**
     * 客户端配置
     */
    @Data
    public static class Client {
        /**
         * 访问令牌
         */
        private String key;

        /**
         * 地址定位渠道
         */
        private Channel channel;
    }

    /**
     * 缓存配置
     */
    @Data
    public static class Caching {
        /**
         * 是否启用缓存
         */
        private boolean enabled = true;

        /**
         * 缓存过期时间（秒）
         */
        private int expiration = 3 * 24 * 60 * 60;
    }
}
