package com.chelvc.framework.location.support;

import java.io.Serializable;

import com.fasterxml.jackson.annotation.JsonAlias;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

/**
 * 腾讯地址定位响应信息
 *
 * @author Woody
 * @date 2024/1/30
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
public class TencentLocationResponse implements Serializable {
    /**
     * 响应状态
     */
    private Integer status;

    /**
     * 描述信息
     */
    private String message;

    /**
     * 地址信息
     */
    private Result result;

    /**
     * 响应结果
     */
    @Data
    @SuperBuilder
    @NoArgsConstructor
    @AllArgsConstructor
    public static class Result implements Serializable {
        /**
         * 定位信息
         */
        private Location location;

        /**
         * 位置信息
         */
        @JsonAlias("ad_info")
        private Position position;

        /**
         * 详细地址
         */
        private String address;
    }

    /**
     * 定位信息
     */
    @Data
    @SuperBuilder
    @NoArgsConstructor
    @AllArgsConstructor
    public static class Location implements Serializable {
        /**
         * 经度
         */
        @JsonAlias("lng")
        private Double longitude;

        /**
         * 维度
         */
        @JsonAlias("lat")
        private Double latitude;
    }

    /**
     * 位置信息
     */
    @Data
    @SuperBuilder
    @NoArgsConstructor
    @AllArgsConstructor
    public static class Position implements Serializable {
        /**
         * 地区编号
         */
        private Integer adcode;

        /**
         * 省
         */
        private String province;

        /**
         * 市
         */
        private String city;

        /**
         * 区
         */
        private String district;
    }
}
