package com.chelvc.framework.nacos.config;

import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

import com.alibaba.cloud.nacos.NacosDiscoveryProperties;
import com.alibaba.cloud.nacos.registry.NacosRegistration;
import com.alibaba.cloud.nacos.registry.NacosServiceRegistry;
import com.chelvc.framework.base.context.ApplicationContextHolder;
import com.chelvc.framework.base.util.SpringUtils;
import com.chelvc.framework.common.util.StringUtils;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.context.event.ApplicationStartedEvent;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationListener;
import org.springframework.core.env.Environment;
import org.springframework.core.io.Resource;

/**
 * 多服务Nacos配置
 * <p>
 * 自动查找工程中所有依赖服务的application.yml配置文件，并将其中的spring.application.name属性值作为服务名称自动注册到Nacos
 *
 * @author Woody
 * @date 2024/1/30
 */
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class MultipleNacosConfigurer implements ApplicationListener<ApplicationStartedEvent> {
    private final NacosServiceRegistry registry;
    private final NacosDiscoveryProperties properties;

    @Override
    public void onApplicationEvent(ApplicationStartedEvent event) {
        ApplicationContext applicationContext = event.getApplicationContext();
        Environment environment = applicationContext.getEnvironment();
        List<Resource> resources = SpringUtils.getPropertyResources(environment);
        String application = ApplicationContextHolder.getApplicationName(environment);
        Set<String> services = resources.stream().map(ApplicationContextHolder::getApplicationName)
                .filter(service -> StringUtils.notEmpty(service) && !service.equals(application))
                .collect(Collectors.toSet());
        services.forEach(service -> {
            this.properties.setService(service);
            this.registry.register(new NacosRegistration(null, this.properties, applicationContext));
        });
    }
}