package com.chelvc.framework.redis.config;

import lombok.Data;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Configuration;

/**
 * Redis缓存配置属性
 *
 * @author Woody
 * @date 2024/1/30
 */
@Data
@Configuration
@ConfigurationProperties("spring.redis")
public class RedisProperties {
    /**
     * 消息流配置
     */
    private final Stream stream = new Stream();

    /**
     * 消息监听配置实例
     */
    private final Listener listener = new Listener();

    /**
     * 消息流配置
     */
    @Data
    public static class Stream {
        /**
         * 消费者空闲时间（秒）
         */
        private int idle = 60;

        /**
         * 消息过期时间（秒）
         */
        private int expiration = 60 * 60;
    }

    /**
     * 消息监听配置
     */
    @Data
    public static class Listener {
        /**
         * 恢复时间间隔
         */
        private long recoveryInterval = 10000;

        /**
         * 最大订阅注册等待时间
         */
        private long maxSubscriptionRegistrationWaitingTime = 5000;
    }
}
