package com.chelvc.framework.redis.queue;

import java.lang.reflect.Type;
import java.util.concurrent.ExecutorService;

import com.chelvc.framework.redis.annotation.RedisMQConsumer;
import org.springframework.beans.factory.DisposableBean;

/**
 * 消息监听器容器接口
 *
 * @param <T> 监听消息对象类型
 * @author Woody
 * @date 2024/1/30
 */
public interface RedisMQListenerContainer<T> extends DisposableBean {
    /**
     * 容器初始化
     *
     * @param type       消息类型
     * @param listener   消息监听器实例
     * @param annotation 消息消费者注解实例
     */
    void initialize(Type type, RedisMQListener<T> listener, RedisMQConsumer annotation);

    /**
     * 容器初始化
     *
     * @param type     消息类型
     * @param topic    消息主题
     * @param group    消费者组
     * @param batch    批量获取消息数量
     * @param listener 消息监听器实例
     * @param executor 消息处理执行器
     */
    void initialize(Type type, String topic, String group, int batch, RedisMQListener<T> listener,
                    ExecutorService executor);

    @Override
    default void destroy() throws Exception {
    }
}
