package com.chelvc.framework.rocketmq.consumer;

import java.util.List;

import com.chelvc.framework.base.context.Session;
import com.chelvc.framework.base.context.SessionContextHolder;
import com.chelvc.framework.common.util.ObjectUtils;
import org.apache.commons.lang3.tuple.Pair;

/**
 * RocketMQ消息消费监听接口
 *
 * @param <T> 消息类型
 * @author Woody
 * @date 2024/1/30
 */
public interface RocketMQListener<T> {
    /**
     * 消费消息
     *
     * @param message 消息实例
     */
    default void consume(T message) {
    }

    /**
     * 批量消费消息
     *
     * @param messages 消息实例列表
     * @return true/false
     */
    default boolean consume(List<Pair<T, Session>> messages) {
        if (ObjectUtils.notEmpty(messages)) {
            messages.forEach(message -> {
                SessionContextHolder.setSession(message.getRight());
                try {
                    this.consume(message.getLeft());
                } finally {
                    SessionContextHolder.removeSessionContext();
                }
            });
        }
        return true;
    }
}
