package com.chelvc.framework.rocketmq.consumer;

import java.lang.reflect.Type;

import com.chelvc.framework.rocketmq.annotation.RocketMQConsumer;
import org.apache.rocketmq.client.apis.ClientConfiguration;
import org.apache.rocketmq.client.apis.ClientServiceProvider;
import org.springframework.beans.factory.DisposableBean;

/**
 * 消息监听器容器接口
 *
 * @param <T> 监听消息对象类型
 * @author Woody
 * @date 2024/1/30
 */
public interface RocketMQListenerContainer<T> extends DisposableBean {
    /**
     * 容器初始化
     *
     * @param type          消息类型
     * @param provider      客户端服务生产者实例
     * @param configuration 客户端配置实例
     * @param listener      消息监听器实例
     * @param annotation    消息消费者注解实例
     */
    void initialize(Type type, ClientServiceProvider provider, ClientConfiguration configuration,
                    RocketMQListener<T> listener, RocketMQConsumer annotation);

    @Override
    default void destroy() throws Exception {
    }
}
