package com.chelvc.framework.security.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * 接口安全校验注解
 *
 * @author Woody
 * @date 2025/3/20
 */
@Documented
@Retention(RetentionPolicy.RUNTIME)
@Target({ElementType.TYPE, ElementType.METHOD})
public @interface Security {
    /**
     * 是否开启签名校验
     *
     * @return true/false
     */
    boolean sign() default false;

    /**
     * 是否开启请求头校验
     *
     * @return true/false
     */
    boolean header() default true;

    /**
     * 是否开启安全校验
     *
     * @return true/false
     */
    boolean enabled() default true;

    /**
     * 是否开启认证校验
     *
     * @return true/false
     */
    boolean authorize() default true;
}
