package com.chelvc.framework.security.config;

import java.util.Collections;
import java.util.List;

import com.chelvc.framework.base.context.Using;
import lombok.Data;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Configuration;

/**
 * 信息安全配置属性
 *
 * @author Woody
 * @date 2024/1/30
 */
@Data
@Configuration
@ConfigurationProperties("security")
public class SecurityProperties {
    /**
     * OAuth认证配置
     */
    private final OAuth oauth = new OAuth();

    /**
     * 加解密配置
     */
    private final Crypto crypto = new Crypto();

    /**
     * 请求配置
     */
    private final Request request = new Request();

    /**
     * 忽略地址列表
     */
    private List<String> ignores = Collections.emptyList();

    /**
     * OAuth认证信息
     */
    @Data
    public static class OAuth {
        /**
         * 令牌密钥
         */
        private String secret;

        /**
         * 是否区分应用范围
         */
        private boolean scoped = false;
    }

    /**
     * 缓存配置
     */
    @Data
    public static class Cache {
        /**
         * 缓存容量
         */
        private int capacity = 100;

        /**
         * 缓存时间（秒）
         */
        private int duration = 60;

        /**
         * 是否启用缓存
         */
        private boolean enabled = false;
    }

    /**
     * 数据加解密配置
     */
    @Data
    public static class Crypto {
        /**
         * 加解密密钥
         */
        private String secret;

        /**
         * 加解密向量
         */
        private String iv;

        /**
         * 加解密缓存配置
         */
        private final Cache cache = new Cache();
    }

    /**
     * 使用配置
     */
    @Data
    public static class Request {
        /**
         * 请求过期时长（毫秒）
         */
        private long expiration = 60 * 1000;

        /**
         * 使用分类刷新时间间隔（毫秒）
         */
        private long usingRefreshInterval = Using.DEFAULT_NEWLY_INTERVAL;
    }
}
