package com.chelvc.framework.security.crypto;

import java.util.Objects;

import com.chelvc.framework.base.context.Session;
import com.chelvc.framework.base.crypto.AbstractCipherHandler;
import com.chelvc.framework.common.util.CodecUtils;
import com.chelvc.framework.common.util.ObjectUtils;
import com.chelvc.framework.common.util.StringUtils;
import com.chelvc.framework.security.config.SecurityProperties;
import lombok.NonNull;

/**
 * 数据安全加解密处理抽象实现
 *
 * @author Woody
 * @date 2025/1/6
 */
public abstract class AbstractSecurityCipherHandler extends AbstractCipherHandler implements SecurityCipherHandler {
    protected final String secret;

    public AbstractSecurityCipherHandler(@NonNull SecurityProperties.Crypto properties) {
        this.secret = Objects.requireNonNull(properties.getSecret());
    }

    @Override
    public String sign(@NonNull Session session, String payload) {
        String id = ObjectUtils.ifNull(session.getId(), String::valueOf, () -> StringUtils.EMPTY);
        String device = ObjectUtils.ifNull(session.getDevice(), StringUtils.EMPTY);
        String terminal = ObjectUtils.ifNull(session.getTerminal(), Enum::name, () -> StringUtils.EMPTY);
        String version = ObjectUtils.ifNull(session.getVersion(), StringUtils.EMPTY);
        String timestamp = ObjectUtils.ifNull(session.getTimestamp(), String::valueOf, () -> StringUtils.EMPTY);
        String plaintext = this.secret + id + device + terminal + version + timestamp + payload;
        return CodecUtils.md5(plaintext);
    }
}
