package com.chelvc.framework.security.firewall;

import java.util.Collections;
import java.util.List;
import java.util.Objects;

import com.chelvc.framework.common.util.ObjectUtils;
import com.google.common.collect.Lists;
import lombok.NonNull;
import lombok.extern.slf4j.Slf4j;

/**
 * 动作执行器默认实现
 *
 * @author Woody
 * @date 2025/3/15
 */
@Slf4j
public class DefaultActionExecutor implements ActionExecutor {
    protected final List<Action> actions;

    public DefaultActionExecutor(@NonNull List<Action> actions) {
        this.actions = Collections.unmodifiableList(actions);
    }

    @Override
    public void execute(String principal, Rule rule) {
        List<Action> matches = null;
        try {
            for (Action action : this.actions) {
                if (Objects.equals(rule.getAction(), action.getName())) {
                    if (matches == null) {
                        matches = Lists.newLinkedList();
                    }
                    matches.add(action);
                    action.execute(principal, rule);
                }
            }
        } finally {
            if (ObjectUtils.isEmpty(matches)) {
                log.warn("Firewall action not found: {}, {}", principal, rule.getAction());
            } else {
                for (Action action : matches) {
                    try {
                        action.complete(principal, rule);
                    } catch (Exception e) {
                        log.error("Firewall action complete failed: {}, {}", principal, action.getName(), e);
                    }
                }
            }
        }
    }
}
