package com.chelvc.framework.security.firewall;

import java.io.Serializable;

import com.chelvc.framework.base.logic.Expression;
import com.chelvc.framework.base.logic.ExpressionJsonDeserializer;
import com.chelvc.framework.base.logic.ExpressionJsonSerializer;
import com.chelvc.framework.base.logic.Variable;
import com.chelvc.framework.base.logic.VariableJsonDeserializer;
import com.chelvc.framework.base.logic.VariableJsonSerializer;
import com.chelvc.framework.common.util.ObjectUtils;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

/**
 * 防火墙防护规则
 *
 * @author Woody
 * @date 2025/2/26
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
public class Rule implements Serializable {
    /**
     * 规则ID
     */
    private String id;

    /**
     * 应用名称
     */
    private String app;

    /**
     * 匹配条件
     */
    @JsonSerialize(using = ExpressionJsonSerializer.class)
    @JsonDeserialize(using = ExpressionJsonDeserializer.class)
    private Expression condition;

    /**
     * 控制主体
     */
    @JsonSerialize(using = VariableJsonSerializer.class)
    @JsonDeserialize(using = VariableJsonDeserializer.class)
    private Variable principal;

    /**
     * 时间窗口（秒）
     */
    private int cycle;

    /**
     * 次数限制
     */
    private int count;

    /**
     * 处理动作
     */
    private String action;

    /**
     * 控制过期时间（秒）
     */
    private int expiration;

    /**
     * 获取规则ID
     *
     * @return 规则ID
     */
    public String getId() {
        if (this.id == null) {
            synchronized (this) {
                if (this.id == null) {
                    this.id = ObjectUtils.md5(this);
                }
            }
        }
        return this.id;
    }

    /**
     * 获取规则ACL标识
     *
     * @param principal 主体标识
     * @return ACL标识
     */
    public String getAclKey(String principal) {
        return "acl:" + principal + ":" + this.getId();
    }

    /**
     * 获取规则访问标识
     *
     * @param principal 主体标识
     * @return 访问标识
     */
    public String getAccessKey(String principal) {
        return "access:" + principal + ":" + this.getId();
    }
}
