package com.chelvc.framework.security.session;

import java.util.Set;

import com.chelvc.framework.base.context.ApplicationContextHolder;
import com.chelvc.framework.base.context.SessionContextHolder;
import com.chelvc.framework.security.context.SecurityContextHolder;
import lombok.extern.slf4j.Slf4j;
import org.springframework.security.oauth2.core.OAuth2AuthenticationException;
import org.springframework.security.oauth2.core.OAuth2Error;
import org.springframework.security.oauth2.core.OAuth2TokenValidatorResult;
import org.springframework.security.oauth2.jwt.Jwt;

/**
 * 会话验证器默认实现
 *
 * @author Woody
 * @date 2024/6/29
 */
@Slf4j
public class DefaultSessionValidator implements SessionValidator {
    /**
     * 获取主体身份
     *
     * @param jwt JWT对象
     * @return 主体身份标识
     */
    protected Long getId(Jwt jwt) {
        try {
            return SecurityContextHolder.getId(jwt);
        } catch (Exception e) {
            log.error("JWT id convert failed", e);
            throw new OAuth2AuthenticationException(new OAuth2Error(
                    "TOKEN_EXPIRED", ApplicationContextHolder.getMessage("Token.Expired"), null
            ));
        }
    }

    /**
     * 获取应用范围
     *
     * @param jwt Jwt对象
     * @return 应用范围
     */
    protected String getScope(Jwt jwt) {
        return SecurityContextHolder.getScope(jwt);
    }

    /**
     * 获取用户授权信息
     *
     * @param jwt JWT对象
     * @return 授权信息集合
     */
    protected Set<String> getAuthorities(Jwt jwt) {
        return SecurityContextHolder.getAuthorities(jwt);
    }

    @Override
    public OAuth2TokenValidatorResult validate(Jwt jwt) {
        if (!SecurityContextHolder.isClient(jwt)) {
            SessionContextHolder.setSession(this.getId(jwt), this.getScope(jwt), this.getAuthorities(jwt));
        }
        return OAuth2TokenValidatorResult.success();
    }
}
