package com.chelvc.framework.security.session;

import com.chelvc.framework.base.context.ApplicationContextHolder;
import org.springframework.security.oauth2.core.OAuth2AuthenticationException;
import org.springframework.security.oauth2.core.OAuth2Error;
import org.springframework.security.oauth2.core.OAuth2TokenValidator;
import org.springframework.security.oauth2.core.OAuth2TokenValidatorResult;
import org.springframework.security.oauth2.jwt.Jwt;
import org.springframework.security.oauth2.jwt.JwtTimestampValidator;

/**
 * 令牌过期验证器实现
 *
 * @author Woody
 * @date 2024/6/23
 */
public class TokenExpiredValidator implements OAuth2TokenValidator<Jwt> {
    private final JwtTimestampValidator delegate = new JwtTimestampValidator();

    @Override
    public OAuth2TokenValidatorResult validate(Jwt jwt) {
        if (this.delegate.validate(jwt).hasErrors()) {
            throw new OAuth2AuthenticationException(new OAuth2Error(
                    "TOKEN_EXPIRED", ApplicationContextHolder.getMessage("Token.Expired"), null
            ));
        }
        return OAuth2TokenValidatorResult.success();
    }
}
