package com.chelvc.framework.sms;

import java.util.function.Predicate;

/**
 * 短信验证码操作接口
 *
 * @author Woody
 * @date 2024/1/30
 */
public interface CaptchaSmsHandler {
    /**
     * 发送验证码
     *
     * @param mobile 手机号
     * @return 短信会话信息
     */
    SmsSession send(String mobile);

    /**
     * 发送验证码
     *
     * @param mobile 手机号
     * @param length 验证码长度
     * @return 短信会话信息
     */
    SmsSession send(String mobile, int length);

    /**
     * 获取验证码信息
     *
     * @param mobile 手机号
     * @return 验证码信息
     */
    Captcha getCaptcha(String mobile);

    /**
     * 使用验证码（使用后移除）
     *
     * @param mobile   手机号
     * @param callback 验证码应用回调接口（返回true则移除验证码）
     */
    void using(String mobile, Predicate<Captcha> callback);

    /**
     * 检测验证码是否正确
     *
     * @param id     令牌标识
     * @param mobile 手机号
     * @param code   验证码
     * @return true/false
     */
    boolean check(String id, String mobile, String code);

    /**
     * 校验验证码是否正确（校验成功后移除）
     *
     * @param id     令牌标识
     * @param mobile 手机号
     * @param code   验证码
     * @return true/false
     */
    boolean validate(String id, String mobile, String code);
}
