package com.chelvc.framework.upload;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;

/**
 * 文件上传操作接口
 *
 * @author Woody
 * @date 2024/1/30
 */
public interface UploadHandler {
    /**
     * 初始化处理器
     */
    default void initialize() {
    }

    /**
     * 刷新CDN
     *
     * @param urls 资源地址数组
     */
    void refreshContentDeliveryNetwork(String... urls);

    /**
     * 文件上传
     *
     * @param file 文件对象
     * @return 文件访问地址
     * @throws IOException I/O异常
     */
    default String upload(File file) throws IOException {
        return this.upload(file, file.getName());
    }

    /**
     * 文件上传
     *
     * @param file     文件对象
     * @param filename 文件名称
     * @return 文件访问地址
     * @throws IOException I/O异常
     */
    String upload(File file, String filename) throws IOException;

    /**
     * 文件上传
     *
     * @param stream   文件流
     * @param filename 文件名称
     * @return 文件访问地址
     * @throws IOException I/O异常
     */
    String upload(InputStream stream, String filename) throws IOException;

    /**
     * 文件上传
     *
     * @param stream   文件流
     * @param filename 文件名称
     * @param length   文件大小
     * @return 文件访问地址
     * @throws IOException I/O异常
     */
    String upload(InputStream stream, String filename, long length) throws IOException;

    /**
     * 销毁处理器
     */
    default void destroy() {
    }
}
