package com.chelvc.framework.upload.config;

import com.chelvc.framework.upload.UploadHandler;
import com.chelvc.framework.upload.support.AliyunUploadHandler;
import com.chelvc.framework.upload.support.LocalUploadHandler;
import com.chelvc.framework.upload.support.TencentUploadHandler;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

/**
 * 文件上传配置
 *
 * @author Woody
 * @date 2024/1/30
 */
@Configuration
public class UploadConfigurer {
    @Bean(initMethod = "initialize", destroyMethod = "destroy")
    @ConditionalOnMissingBean(UploadHandler.class)
    public UploadHandler uploadHandler(UploadProperties properties) {
        UploadProperties.Channel channel = properties.getChannel();
        if (channel == UploadProperties.Channel.LOCAL) {
            return new LocalUploadHandler(properties);
        } else if (channel == UploadProperties.Channel.ALIYUN) {
            return new AliyunUploadHandler(properties);
        } else if (channel == UploadProperties.Channel.TENCENT) {
            return new TencentUploadHandler(properties);
        }
        throw new UnsupportedOperationException(String.valueOf(channel));
    }
}
