package com.chelvc.framework.upload.support;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;

import com.chelvc.framework.base.util.HttpUtils;
import com.chelvc.framework.common.util.AssertUtils;
import com.chelvc.framework.common.util.FileUtils;
import com.chelvc.framework.common.util.StringUtils;
import com.chelvc.framework.upload.UploadHandler;
import com.chelvc.framework.upload.config.UploadProperties;
import lombok.NonNull;

/**
 * 文件本地上传实现
 *
 * @author Woody
 * @date 2024/1/30
 */
public class LocalUploadHandler implements UploadHandler {
    private final String bucket;
    private final String domain;

    public LocalUploadHandler(@NonNull UploadProperties properties) {
        this.bucket = properties.getBucket();
        this.domain = properties.getDomain();
        AssertUtils.arg(StringUtils.notEmpty(this.bucket), () -> "Local upload bucket is missing");
        AssertUtils.arg(StringUtils.notEmpty(this.domain), () -> "Local upload access domain is missing");
    }

    @Override
    public void refreshContentDeliveryNetwork(String... urls) {
        throw new UnsupportedOperationException();
    }

    @Override
    public String upload(@NonNull File file, @NonNull String filename) throws IOException {
        FileUtils.write(new File(this.bucket, filename), file);
        return HttpUtils.url(this.domain, filename);
    }

    @Override
    public String upload(@NonNull InputStream stream, @NonNull String filename) throws IOException {
        return this.upload(stream, filename, stream.available());
    }

    @Override
    public String upload(@NonNull InputStream stream, @NonNull String filename, long length) throws IOException {
        FileUtils.write(new File(this.bucket, filename), stream);
        return HttpUtils.url(this.domain, filename);
    }
}
