package com.chelvc.framework.wechat;

import java.util.Map;

/**
 * 微信支付处理器接口
 *
 * @author Woody
 * @date 2024/6/19
 */
public interface WechatPaymentProcessor {
    /**
     * 获取应用名称
     *
     * @return 应用名称
     */
    String getName();

    /**
     * 获取应用标识
     *
     * @return 引用标识
     */
    String getAppid();

    /**
     * 获取商户号
     *
     * @return 商户号
     */
    String getMchid();

    /**
     * 获取支付方式
     *
     * @return 支付方式
     */
    PayMode getMode();

    /**
     * 获取支付渠道
     *
     * @return 支付渠道
     */
    PayChannel getChannel();

    /**
     * 获取支付回调地址
     *
     * @return 支付回调地址
     */
    String getCallback();

    /**
     * 参数签名
     *
     * @param parameters 签名参数
     * @return 签名信息
     */
    String sign(Map<String, String> parameters);

    /**
     * 支付回调参数解析
     *
     * @param content 支付回调内容
     * @return 支付回调信息
     */
    WechatPaymentCallback callback(String content);

    /**
     * 微信统一下单
     *
     * @param request 支付请求参数
     * @return 微信统一下单信息
     */
    WechatUnifiedOrder unifiedorder(WechatPayRequest request);
}
